@@ -57,7 +57,7 @@ enum { GAMGI_CHEM_CONTAINER = 1, GAMGI_CHEM_POLYTOPE };
 enum { GAMGI_CHEM_STRUCTURE_COPY = 1, GAMGI_CHEM_STRUCTURE_LINK,
 GAMGI_CHEM_STRUCTURE_NONE };
 
-enum { GAMGI_CHEM_FILTER_CLASS = 1, GAMGI_CHEM_FILTER_CHILD,
+enum { GAMGI_CHEM_FILTER_CLASS = 1, GAMGI_CHEM_FILTER_PARENT,
 GAMGI_CHEM_FILTER_IDENTICAL, GAMGI_CHEM_FILTER_NONE };
 
 /******************************************
