@@ -93,7 +93,7 @@ return start;
 }
 
 gamgi_dlist *gamgi_engine_filter_atom_class (gamgi_dlist *start,
-gamgi_enum class)
+int offset, gamgi_enum class)
 {
 gamgi_object *object;
 gamgi_dlist *dlist;
@@ -104,6 +104,8 @@ gamgi_dlist *dlist;
 
 for (dlist = start; dlist != NULL; dlist = dlist->next)
   {
+  if (offset-- > 0) continue;
+
   object = GAMGI_CAST_OBJECT dlist->data;
   if (object->object->class == class)
     {
@@ -115,8 +117,8 @@ for (dlist = start; dlist != NULL; dlist = dlist->next)
 return start;
 }
 
-gamgi_dlist *gamgi_engine_filter_atom_child (gamgi_dlist *start,
-gamgi_object *parent)
+gamgi_dlist *gamgi_engine_filter_atom_parent (gamgi_dlist *start,
+int offset, gamgi_object *parent)
 {
 gamgi_object *object;
 gamgi_dlist *dlist;
@@ -127,6 +129,8 @@ gamgi_dlist *dlist;
 
 for (dlist = start; dlist != NULL; dlist = dlist->next)
   {
+  if (offset-- > 0) continue;
+
   object = GAMGI_CAST_OBJECT dlist->data;
   if (object->object != parent)
     {
@@ -138,7 +142,7 @@ for (dlist = start; dlist != NULL; dlist = dlist->next)
 return start;
 }
 
-gamgi_dlist *gamgi_engine_filter_atom_identical (gamgi_dlist *start)
+gamgi_dlist *gamgi_engine_filter_atom_identical (gamgi_dlist *start, int offset)
 {
 gamgi_atom *atom_i, *atom_j;
 gamgi_dlist *dlist_i, *dlist_j;
@@ -146,6 +150,8 @@ double x, y, z;
 
 for (dlist_i = start; dlist_i != NULL; dlist_i = dlist_i->next)
   {
+  if (offset-- > 0) continue;
+
   atom_i = GAMGI_CAST_ATOM dlist_i->data;
 
   dlist_j = dlist_i->next;
@@ -166,18 +172,18 @@ for (dlist_i = start; dlist_i != NULL; dlist_i = dlist_i->next)
 return start;
 }
 
-gamgi_dlist *gamgi_engine_filter_atom (gamgi_dlist *dlist,
-gamgi_enum filter, gamgi_enum class, gamgi_object *parent)
+gamgi_dlist *gamgi_engine_filter_atom (gamgi_dlist *start,
+int offset, gamgi_enum filter, gamgi_enum class, gamgi_object *parent)
 {
 if (filter == GAMGI_CHEM_FILTER_CLASS)
   while (class > GAMGI_ENGINE_ATOM)
-    dlist = gamgi_engine_filter_atom_class (dlist, class--);
+    start = gamgi_engine_filter_atom_class (start, offset, class--);
 
-if (filter == GAMGI_CHEM_FILTER_CHILD)
-  dlist = gamgi_engine_filter_atom_child (dlist, parent);
+if (filter == GAMGI_CHEM_FILTER_PARENT)
+  start = gamgi_engine_filter_atom_parent (start, offset, parent);
 
 if (filter == GAMGI_CHEM_FILTER_IDENTICAL)
-  dlist = gamgi_engine_filter_atom_identical (dlist);
+  start = gamgi_engine_filter_atom_identical (start, offset);
 
-return dlist;
+return start;
 }
