@@ -110,9 +110,6 @@ void gamgi_mesa_start_direction (gamgi_direction *direction, gamgi_direction_cla
 {
 direction->vectors = GAMGI_PHYS_DIRECTION_VECTORS;
 direction->reference = GAMGI_ENGINE_CELL;
-direction->structure = GAMGI_CHEM_STRUCTURE;
-direction->filter = GAMGI_CHEM_FILTER;
-direction->thickness = GAMGI_CHEM_DIRECTION_THICKNESS;
 
 /*********
  * color *
@@ -135,9 +132,6 @@ void gamgi_mesa_start_plane (gamgi_plane *plane, gamgi_plane_class *plane_class)
 {
 plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
 plane->reference = GAMGI_ENGINE_CELL;
-plane->structure = GAMGI_CHEM_STRUCTURE;
-plane->filter = GAMGI_CHEM_FILTER;
-plane->thickness = GAMGI_CHEM_PLANE_THICKNESS;
 
 /*********
  * color *
